Crate unwind_unsafe

source ·
This crate provides zero-sized marker types which do not implement UnwindSafe or RefUnwindSafe. They can be added to types to prevent the respective auto traits from being derived.

These types can be instantiated via their Default implementation or from their associated constant DEFAULT.

This crate has no dependencies, no unsafe code, and is no_std by default.

Structs